instrumenttools.notes_and_chords_in_expr_are_within_traditional_instrument_ranges
=================================================================================

.. autofunction:: abjad.tools.instrumenttools.notes_and_chords_in_expr_are_within_traditional_instrument_ranges.notes_and_chords_in_expr_are_within_traditional_instrument_ranges
